'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var deviceManager = function deviceManager(base) {
  base = base + '/devices';
  return {
    /**
    * @summary Get all or single device definition
    * @name get
    * @public
    * @function
    * @memberof agile.deviceManager
    * @param {String} [deviceId] - Agile device Id
    * @fulfil {Array} - devices
    * @returns {Promise}
    * @example
    * agile.deviceManager.get('bleB0B448BE5084').then(function(device) {
    *   console.log(device);
    * });
    **/
    get: function get(deviceId) {
      var url = '' + base;
      if (deviceId) {
        url = base + '/' + deviceId;
      }
      return (0, _axios2.default)({
        method: 'GET',
        url: url
      });
    },
    /**
    * @summary Delete a device definition and unregister it
    * @name delete
    * @public
    * @function
    * @memberof agile.deviceManager
    * @param {String} deviceId - Agile device Id
    * @fulfil {undefined}
    * @returns {Promise}
    * @example
    * agile.deviceManager.delete('bleB0B448BE5084').then(function() {
    *   console.log('Device bleB0B448BD1085 deleted');
    * });
    **/
    delete: function _delete(deviceId) {
      return (0, _axios2.default)({
        method: 'DELETE',
        url: base + '/' + deviceId
      });
    },
    /**
    * @summary Register a new device based on information from ProtocolManager and device type
    * @name create
    * @public
    * @function
    * @memberof agile.deviceManager
    * @param {Object} deviceOverview
    * @param {string} type
    * @fulfil {Object} - device
    * @returns {Promise}
    * @example
    * const deviceOverview = {
    *   "name": "CC2650 SensorTag",
    *   "protocol": "iot.agile.protocol.BLE",
    *   "id": "B0:B4:48:BD:10:85",
    *   "status": "CONNECTED"
    * };
    * const type = "TI SensorTag";
    *
    * agile.deviceManager.create(deviceOverview, type).then(function(newDevice) {
    *  console.log(newDevice);
    * });
    **/
    create: function create(deviceOverview, type) {
      return (0, _axios2.default)({
        method: 'POST',
        url: '' + base,
        data: {
          overview: deviceOverview,
          type: type
        }
      });
    },
    /**
    * @summary Get matching types for a device overview
    * @name typeof
    * @public
    * @function
    * @memberof agile.deviceManager
    *
    * @param {Object} deviceOverview
    * @fulfil {Array} - deviceTypes
    * @returns {Promise}
    * @example
    * const deviceOverview = {
    *   "name": "CC2650 SensorTag",
    *   "protocol": "iot.agile.protocol.BLE",
    *   "id": "B0:B4:48:BD:10:85",
    *   "status": "CONNECTED"
    * };
    *
    * agile.deviceManager.typeof(deviceOverview).then(function(deviceTypes) {
    *  console.log(deviceTypes);
    * });
    **/
    typeof: function _typeof(deviceOverview) {
      return (0, _axios2.default)({
        method: 'POST',
        url: base + '/typeof',
        data: deviceOverview
      });
    }
  };
}; /*******************************************************************************
    * Copyright (C) 2018 resin.io, and others
    *
    * This program and the accompanying materials are made
    * available under the terms of the Eclipse Public License 2.0
    * which is available at https://www.eclipse.org/legal/epl-2.0/
    *
    * SPDX-License-Identifier: EPL-2.0
    ******************************************************************************/
exports.default = deviceManager;